@@ -6,9 +6,9 @@ import logging
 import os
 import subprocess
 
-def setup_logging(args, uuid):
+def setup_logging(args, task_uuid):
     logging.basicConfig(
-        filename=os.path.join(uuid + '.log'),
+        filename=os.path.join(task_uuid + '.log'),
         level=args.level,
         filemode='w',
         format='%(asctime)s %(levelname)s %(message)s',
@@ -37,9 +37,11 @@ def get_connect_dict(config_path, ini_section):
     return connect_dict
 
 def allow_create_fail(sql_path, logger):
-    shell_cmd = "sed 's/CREATE TABLE/CREATE TABLE IF NOT EXISTS/g' " + sql_path + " > create_table.sql"
+    shell_cmd = "sed '/PRAGMA/d' " + sql_path + " > pragma_free.sql"
     output = subprocess.check_output(shell_cmd, shell=True)
-    shell_cmd = "sed 's/CREATE INDEX/CREATE INDEX IF NOT EXISTS/g' create_table.sql > " + sql_path
+    shell_cmd = "sed 's/CREATE TABLE/CREATE TABLE IF NOT EXISTS/g' pragma_free.sql > create_table.sql"
+    output = subprocess.check_output(shell_cmd, shell=True)
+    shell_cmd = "sed '/CREATE INDEX/d' create_table.sql > " + sql_path
     output = subprocess.check_output(shell_cmd, shell=True)
     return
 
@@ -57,15 +59,15 @@ def main():
     parser.add_argument('--source_sqlite_path', required=True)
     parser.add_argument('--postgres_creds_path', required=False)
     parser.add_argument('--ini_section', required=True)
-    parser.add_argument('--uuid', required=True)
+    parser.add_argument('--task_uuid', required=True)
     args = parser.parse_args()
 
     ini_section = args.ini_section
     postgres_creds_path = args.postgres_creds_path
     source_sqlite_path = args.source_sqlite_path
-    uuid = args.uuid
+    task_uuid = args.task_uuid
     
-    logger = setup_logging(args, uuid)
+    logger = setup_logging(args, task_uuid)
 
     source_sqlite_name, source_sqlite_ext = os.path.splitext(os.path.basename(source_sqlite_path))
     logger.info('source_sqlite_name = %s' % source_sqlite_name)
